# thumbor-distributed-collage-filter

Distributed collage is a filter for creating side-by-side images.

## Installing

```
    pip install thumbor-distributed-collage-filter
```

## Usage

In your thumbor.conf file, use the following:

```
FILTERS = [
    # thumbor filters ...
    'thumbor_distributed_collage_filter.filter',
]
```

## URL Arguments

TODO: Write docs for this filter.

## License

MIT Licensed.
